@@ -1,8 +1,8 @@
 # coding:utf-8
 import os, sys
+from .config import *
 
 
-from .config import LIB_DIR, FASTBERT_HOME_DIR
 sys.path.append(LIB_DIR)
 if not os.path.exists(FASTBERT_HOME_DIR):
     os.mkdir(FASTBERT_HOME_DIR)
